@@ -31,8 +31,10 @@
 
 #include "global.h"
 
-void
-about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
+static void
+about_cb (BonoboUIComponent *uic,
+	  MultiloadApplet   *ma,
+	  const char        *name)
 {
     static GtkWidget *about = NULL;
     GdkPixbuf        *pixbuf;
@@ -53,12 +55,10 @@ about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 
     const gchar *translator_credits = _("translator_credits");
 
-    if (about != NULL)
-	{
-	    gdk_window_show(about->window);
-	    gdk_window_raise(about->window);
-	    return;
-	}
+    if (about) {
+	gtk_window_present (GTK_WINDOW (about));
+	return;
+    }
 	
     file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-monitor.png", FALSE, NULL);
     pixbuf = gdk_pixbuf_new_from_file (file, &error);
@@ -85,8 +85,6 @@ about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
    	gdk_pixbuf_unref (pixbuf);
    
     gtk_window_set_wmclass (GTK_WINDOW (about), "system monitor", "System Monitor");
-    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-monitor.png");
-
     g_signal_connect (G_OBJECT (about), "destroy",
 			G_CALLBACK (gtk_widget_destroyed), &about);
 
@@ -95,11 +93,35 @@ about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 
 /* run the full-scale system process monitor */
 
-void
-start_procman_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
+static void
+start_procman_cb (BonoboUIComponent *uic,
+		  MultiloadApplet   *ma,
+		  const char        *name)
 {
-	gnome_execute_shell(NULL, "gnome-system-monitor");
-	return;
+	GError *error = NULL;
+
+	g_spawn_command_line_async ("gnome-system-monitor", &error);
+	if (error) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("There was an error executing '%s' : %s"),
+						 "gnome-system-monitor",
+						 error->message);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+		gtk_widget_show (dialog);
+
+		g_error_free (error);
+	}
 }
               
 void
@@ -257,8 +279,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	if ( (orientation == PANEL_APPLET_ORIENT_UP) || 
 	     (orientation == PANEL_APPLET_ORIENT_DOWN) ) {
-	     	g_print ("hbox \n");
-		ma->box = gtk_hbox_new(FALSE, 0);
+	     	ma->box = gtk_hbox_new(FALSE, 0);
 	}
 	else
 		ma->box = gtk_vbox_new(FALSE, 0);
@@ -289,6 +310,14 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	return;
 }
 
+static const BonoboUIVerb multiload_menu_verbs [] = {
+	BONOBO_UI_UNSAFE_VERB ("MultiLoadProperties", multiload_properties_cb),
+	BONOBO_UI_UNSAFE_VERB ("MultiLoadRunProcman", start_procman_cb),
+	BONOBO_UI_UNSAFE_VERB ("MultiLoadAbout", about_cb),
+
+	BONOBO_UI_VERB_END
+};		
+
 /* create a box and stuff the load graphs inside of it */
 gboolean
 multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
@@ -297,11 +326,14 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	GtkWidget *box;
 	PanelAppletOrient orientation;
 	MultiloadApplet *ma;
+	gboolean visible = FALSE;
 	
 	ma = g_new0(MultiloadApplet, 1);
 	
 	ma->applet = applet;
 	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
+	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
 	
 	orientation = panel_applet_get_orient(applet);
@@ -328,26 +360,26 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	    if (ma->graphs[i]->visible) {
 	    	gtk_widget_show_all (ma->graphs[i]->main_widget);
 		load_graph_start(ma->graphs[i]);
+		visible = TRUE;
 	    }
 	}
-
-	{
-		/* we need to pass 'ma' into the properties_cb or else every instance of multiload will use the same properties dialog*/
-		const BonoboUIVerb multiload_menu_verbs [] = {
-			BONOBO_UI_VERB_DATA ("MultiLoadProperties", multiload_properties_cb, ma),
-			BONOBO_UI_VERB ("MultiLoadRunProcman", start_procman_cb),
-	        BONOBO_UI_VERB ("MultiLoadAbout", about_cb),
-
-  	      BONOBO_UI_VERB_END
-		};		
-		panel_applet_setup_menu_from_file (applet,
-						   NULL,
-						   "GNOME_MultiloadApplet.xml",
-						   NULL,
-						   multiload_menu_verbs,
-						   ma);	
+	
+	if (!visible) {
+		/* No graphs shown - need to show at least one so show cpu*/
+		ma->graphs[0]->visible = TRUE;
+		gtk_widget_show_all (ma->graphs[0]->main_widget);
+		load_graph_start(ma->graphs[0]);
+		panel_applet_gconf_set_bool(ma->applet, "view_cpuload", 
+			                    TRUE, NULL);
 	}
 
+	panel_applet_setup_menu_from_file (applet,
+					   NULL,
+					   "GNOME_MultiloadApplet.xml",
+					   NULL,
+					   multiload_menu_verbs,
+					  ma);	
+
 	ma->box = box;
 	
 	g_signal_connect(G_OBJECT(applet), "change_size",
